summaryrefslogtreecommitdiff
path: root/accessibility/inc/accessibility/extended/AccessibleBrowseBoxTableBase.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'accessibility/inc/accessibility/extended/AccessibleBrowseBoxTableBase.hxx')
-rw-r--r--accessibility/inc/accessibility/extended/AccessibleBrowseBoxTableBase.hxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/accessibility/inc/accessibility/extended/AccessibleBrowseBoxTableBase.hxx b/accessibility/inc/accessibility/extended/AccessibleBrowseBoxTableBase.hxx
index fa6ce94cfc7f..f4efb30466ae 100644
--- a/accessibility/inc/accessibility/extended/AccessibleBrowseBoxTableBase.hxx
+++ b/accessibility/inc/accessibility/extended/AccessibleBrowseBoxTableBase.hxx
@@ -191,7 +191,7 @@ protected:
// internal helper methods ------------------------------------------------
/** @return <TRUE/>, if first BrowseBox column is the "handle column". */
sal_Bool implHasHandleColumn() const;
/** @attention This method requires locked mutex's and a living object.
@@ -217,19 +217,19 @@ protected:
sal_Int32 implGetChildIndex( sal_Int32 nRow, sal_Int32 nColumn ) const;
/** @attention This method requires locked mutex's and a living object.
- @return <TRUE/>, if the specified row is selected. */
+ @return <sal_True/>, if the specified row is selected. */
sal_Bool implIsRowSelected( sal_Int32 nRow ) const;
/** @attention This method requires locked mutex's and a living object.
- @return <TRUE/>, if the specified column is selected. */
+ @return <sal_True/>, if the specified column is selected. */
sal_Bool implIsColumnSelected( sal_Int32 nColumn ) const;
/** Selects/deselects a row (tries to expand selection).
@attention This method requires locked mutex's and a living object.
- @param bSelect <TRUE/> = select, <FALSE/> = deselect */
+ @param bSelect <sal_True/> = select, <sal_False/> = deselect */
void implSelectRow( sal_Int32 nRow, sal_Bool bSelect );
/** Selects/deselects a column (tries to expand selection).
@attention This method requires locked mutex's and a living object.
- @param bSelect <TRUE/> = select, <FALSE/> = deselect */
+ @param bSelect <sal_True/> = select, <sal_False/> = deselect */
void implSelectColumn( sal_Int32 nColumnPos, sal_Bool bSelect );
/** @attention This method requires locked mutex's and a living object.
@@ -191,7 +191,7 @@ protected:
// internal helper methods ------------------------------------------------
- /** @return <TRUE/>, if first BrowseBox column is the "handle column". */
+ /** @return <sal_True/>, if first BrowseBox column is the "handle column". */
sal_Bool implHasHandleColumn() const;
/** @attention This method requires locked mutex's and a living object.